@@ -62,6 +62,19 @@ dcc <- function(chrono, clim, method = "response", start = -6, end =
     interval.clim <-(start.year + offset):end.year
     interval.chrono <- (start.year + 1 + offset):end.year
   }
+  if (start*end > 0) {
+    no.params <- (dim(clim)[2] -2)*length(start:end)
+  } else {
+    no.params <- (dim(clim)[2] -2)*length(start:end)-1 # 0 is not counted
+  }
+  overlap.size <- length(start.year:end.year)
+  ## raise error, when window size is smaller than number of params
+  if (no.params > overlap.size) {
+    win.size.msg <-
+      paste("Overlapping time span of chrono and climate records is smaller than number of parameters! Consider adapting the number of parameters to a maximum of ",
+            overlap.size, ".", sep = "")
+    stop(win.size.msg)
+  }
   a <- as.numeric(rownames(chrono)) %in% interval.chrono
   b <- clim[, 1] %in% interval.clim
   chrono.trunc <- chrono[a, 1] # truncate data 
